==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/petitions/lang/petitions_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vous allez supprimer toutes les signatures de cette p&eacute;tition. &Ecirc;tes-vous sur de vouloir continuer ?', # NEW
	'aucune_signature' => 'Aucune signature', # NEW

	// B
	'bouton_checkbox_envoi_message' => 'possibilit&eacute; d\'envoyer un message', # NEW
	'bouton_checkbox_indiquer_site' => 'indiquer obligatoirement un site web', # NEW
	'bouton_checkbox_signature_unique_email' => 'une seule signature par adresse email', # NEW
	'bouton_checkbox_signature_unique_site' => 'une seule signature par site web', # NEW

	// F
	'filtre' => 'Filtre :', # NEW
	'form_pet_adresse_site' => 'Adreiça dau vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Minga de signatura non correspònde a aqueu còde...',
	'form_pet_confirmation' => 'Vorgatz confirmar la vòstra signatura:',
	'form_pet_deja_signe' => 'Avètz ja signat aqueu tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Aüra recebretz un e-mail de confirmacion. Per validar la vòstra signatura, cau vesitar l\'adreiça web mençonada per aquest corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Bònjorn,

avètz demandat de signar la peticion:
@titre@.

Avètz fornit li informacions seguenti :
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar la vòstra signatura, basta de vos connectar a 
 l\'adreiça çai sota (senon s\'escamparà
 la vòstra demanda): 
    @url@


Mercé per la vòstra participacion
',
	'form_pet_message_commentaire' => 'Un messatge, una remarca?', # MODIF
	'form_pet_nom_site2' => 'Nom dau vòstre sit web', # MODIF
	'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
	'form_pet_probleme_technique' => 'Problèma tecnic, li signaturas son temporàriament arrestadi.',
	'form_pet_signature_validee' => 'La vòstra signatura es validada. Mercé!',
	'form_pet_site_deja_enregistre' => 'Ja aqueu sit es registrat',
	'form_pet_url_invalide' => 'L\'URL qu\'avètz indicada non es valida.',
	'form_pet_votre_email' => 'La vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Lo vòstre nom ò pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, o podètz marcar çai sota',

	// I
	'icone_relancer_signataire' => 'Relancer le signataire', # NEW
	'icone_relancer_signataires' => 'Relancer les signataires', # NEW
	'icone_suivi_petitions' => 'Suivre/g&eacute;rer les p&eacute;titions', # NEW
	'icone_supprimer_signature' => 'Supprimer cette signature', # NEW
	'icone_supprimer_signatures' => 'Supprimer les signatures', # NEW
	'icone_valider_signature' => 'Valider cette signature', # NEW
	'icone_valider_signatures' => 'Valider les signatures', # NEW
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_fonctionnement_petition' => 'Fonctionnement de la p&eacute;tition :', # NEW
	'info_signature_supprimee' => 'Signature supprimée', # NEW
	'info_signature_supprimee_erreur' => 'Erreur : ce code de suppression ne correspond a aucune signature', # NEW
	'info_site_web' => 'SIT WEB:',
	'info_texte_message' => 'Tèxt dau vòstre messatge:',

	// L
	'lien_reponse_article' => 'Respòsta a l\'article',

	// N
	'nombre_signatures' => '@nb@ signatures', # NEW

	// S
	'sans_nom' => 'Anonyme', # NEW
	'signatures_article' => 'Signatures de l\'article :', # NEW
	'signatures_aucune' => 'Aucune', # NEW
	'signatures_meme_auteur' => 'Les signatures du m', # NEW
	'signatures_meme_site' => 'Les signatures avec le m', # NEW
	'signatures_poubelle' => 'Supprim&eacute;es', # NEW
	'signatures_prop' => 'En attente', # NEW
	'signatures_publie' => 'Confirm&eacute;es', # NEW
	'signatures_recherche_label' => 'Rechercher des signatures&nbsp;:', # NEW
	'signatures_toutes' => 'Toutes', # NEW
	'statut_poubelle' => 'Supprim&eacute;e', # NEW
	'statut_prop' => 'En attente de validation', # NEW
	'statut_publie' => 'Confirm&eacute;e', # NEW

	// T
	'texte_descriptif_petition' => 'Descriptif de la p&eacute;tition', # NEW
	'titre_page_controle_petition' => 'Suivi des p&eacute;titions', # NEW
	'titre_petition' => 'P&eacute;tition', # NEW
	'titre_petitions' => 'P&eacute;titions', # NEW
	'titre_selection_action' => 'Sélection', # NEW
	'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
	'titre_signatures_publie' => 'Signatures confirm&eacute;es', # NEW
	'titre_suivi_petition' => 'Suivi des p&eacute;titions', # NEW
	'tout_voir' => 'Voir toutes les signatures', # NEW

	// U
	'une_signature' => '1 signature', # NEW

	// V
	'voir_signatures_objet' => 'Voir les signatures' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/petitions/lang/petitions_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la peticion',
	'bouton_radio_pas_petition' => 'Minga de peticion',
	'bouton_radio_petition_activee' => 'Peticion activada',
	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',

	// F
	'form_pet_adresse_site' => 'Adreiça dau vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Minga de signatura non correspònde a aqueu còde...', # MODIF
	'form_pet_confirmation' => 'Vorgatz confirmar la vòstra signatura:',
	'form_pet_deja_signe' => 'Avètz ja signat aqueu tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Aüra recebretz un e-mail de confirmacion. Per validar la vòstra signatura, cau vesitar l’adreiça web mençonada per aquest corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Bònjorn,

avètz demandat de signar la peticion:
@titre@.

Avètz fornit li informacions seguenti :
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar la vòstra signatura, basta de vos connectar a 
 l’adreiça çai sota (senon s’escamparà
 la vòstra demanda): 
    @url@


Mercé per la vòstra participacion
',
	'form_pet_message_commentaire' => 'Un messatge, una remarca?', # MODIF
	'form_pet_nom_site2' => 'Nom dau vòstre sit web', # MODIF
	'form_pet_probleme_technique' => 'Problèma tecnic, li signaturas son temporàriament arrestadi.',
	'form_pet_signature_validee' => 'La vòstra signatura es validada. Mercé!',
	'form_pet_site_deja_enregistre' => 'Ja aqueu sit es registrat',
	'form_pet_url_invalide' => 'L’URL qu’avètz indicada non es valida.',
	'form_pet_votre_email' => 'La vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Lo vòstre nom ò pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, o podètz marcar çai sota',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Respòsta a l’article'
);

?>
